Practice Problems
-----------------------------------------------------

Please answer
the following problems to the best of your ability without any
outside help. You can stop working on a problem after you worked
on it for about five minutes without solving it.

.. selectquestion:: class-song-pnd-sq
   :fromid: Classes_Basic_Song_nd_pp
   :points: 10

.. selectquestion:: class-cat-pnd-sq
   :fromid: Classes_Basic_Cat_nd_pp
   :points: 10

.. selectquestion:: class-account-pnd-sq
   :fromid: Classes_Basic_Account_nd_pp
   :points: 10

.. selectquestion:: class-fortune-pnd-sq
   :fromid: Classes_Basic_FortuneTeller_nd_pp
   :points: 10

Feedback
============================

.. shortanswer:: class-pnd-sa

   Please provide feedback here. Please share any comments, problems, or suggestions.


What to do next
============================
.. raw:: html

    <p>Click on the following link to go to the post test: <b><a id="class-post"><font size="+2">Post Test</font></a></b></p>

.. raw:: html

    <script type="text/javascript" >

      window.history.pushState(null, null, window.location.href);
      window.onpopstate = function () {
          window.history.go(1);
      }

      window.onload = function() {

        a = document.getElementById("class-post")
        a.href = "class-post.html"
      };

    </script>
